Integer of the value-index on which the read process starts, default: 1.
endIndex
Integer of the value-index on which the read process ends, default: last Index of file.
readInChunks
Boolean determines if the reading process is done in chunks.
This could be useful if you run into memory limits when reading big files. default: FALSE.
readChunkSize
Integer defining the size of chunks if chunk reading is enabled, defined in samples, default: 2^16.